summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorNeil Fortner <nfortne2@hdfgroup.org>2015-01-02 16:24:14 (GMT)
committerNeil Fortner <nfortne2@hdfgroup.org>2015-01-02 16:24:14 (GMT)
commitf8f7c0dfaaf33ae0d69fd077a68bcb3239c4b9ec (patch)
treeb0d3b44c708f17a061efdd3019880624a60e3729 /src
parent073252b22a214c627b2ff9ca9b8d5c6bb25508f0 (diff)
downloadhdf5-f8f7c0dfaaf33ae0d69fd077a68bcb3239c4b9ec.zip
hdf5-f8f7c0dfaaf33ae0d69fd077a68bcb3239c4b9ec.tar.gz
hdf5-f8f7c0dfaaf33ae0d69fd077a68bcb3239c4b9ec.tar.bz2
[svn-r25941] Fix uninitialized memory error with v2 b-tree shadow pointers
Fix swmr_writer and swmr_remove_writer to handle user-supplied seed values greater than 2^31-1
Diffstat (limited to 'src')
-rw-r--r--src/H5B2int.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/H5B2int.c b/src/H5B2int.c
index b8c5c8c..eea1ca7 100644
--- a/src/H5B2int.c
+++ b/src/H5B2int.c
@@ -2562,8 +2562,9 @@ HDmemset(leaf->leaf_native, 0, hdr->cls->nrec_size * hdr->node_info[0].max_nrec)
/* Set parent */
leaf->parent = parent;
/* Set shadowed list next pointer */
leaf->shadowed_next = NULL;
+ leaf->shadowed_prev = NULL;
/* Allocate space on disk for the leaf */
if(HADDR_UNDEF == (node_ptr->addr = H5MF_alloc(hdr->f, H5FD_MEM_BTREE, dxpl_id, (hsize_t)hdr->node_size)))
@@ -2688,8 +2689,9 @@ HDmemset(internal->node_ptrs, 0, sizeof(H5B2_node_ptr_t) * (hdr->node_info[depth
/* Set parent */
internal->parent = parent;
/* Set shadowed list next pointer */
internal->shadowed_next = NULL;
+ internal->shadowed_prev = NULL;
/* Allocate space on disk for the internal node */
if(HADDR_UNDEF == (node_ptr->addr = H5MF_alloc(hdr->f, H5FD_MEM_BTREE, dxpl_id, (hsize_t)hdr->node_size)))
@@ -2562,8 +2562,9 @@ HDmemset(leaf->leaf_native, 0, hdr->cls->nrec_size * hdr->node_info[0].max_nrec)
/* Set parent */
leaf->parent = parent;
- /* Set shadowed list next pointer */
+ /* Set shadowed list next and prev pointers */
leaf->shadowed_next = NULL;
@@ -2688,8 +2689,9 @@ HDmemset(internal->node_ptrs, 0, sizeof(H5B2_node_ptr_t) * (hdr->node_info[depth
/* Set parent */
internal->parent = parent;
- /* Set shadowed list next pointer */
+ /* Set shadowed list next and prev pointers */
internal->shadowed_next = NULL;